##  Check the Profile Details
  1. Choose a (test) user that has specific user group assignments or put your own user into the AD user groups.
  2. Open an incognito browser window and log in to SAP LeanIX.
  3. Select the profile icon.
If the SSO configuration was successful, the access control entities are visible.

![Profile Details with entry ACI values](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274345547a441014843e824ae6198109_LowRes.png)
